@@ -17,6 +17,12 @@ __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_OneWire.git"
 import busio
 from micropython import const
 
+try:
+    from typing import Optional, List, Tuple
+    from microcontroller import Pin
+except ImportError:
+    pass
+
 _SEARCH_ROM = const(0xF0)
 _MATCH_ROM = const(0x55)
 _SKIP_ROM = const(0xCC)
@@ -30,26 +36,26 @@ class OneWireError(Exception):
 class OneWireAddress:
     """A class to represent a 1-Wire address."""
 
-    def __init__(self, rom):
+    def __init__(self, rom: bytearray) -> None:
         self._rom = rom
 
     @property
-    def rom(self):
+    def rom(self) -> bytearray:
         """The unique 64 bit ROM code."""
         return self._rom
 
     @property
-    def crc(self):
+    def crc(self) -> int:
         """The 8 bit CRC."""
         return self._rom[7]
 
     @property
-    def serial_number(self):
+    def serial_number(self) -> bytearray:
         """The 48 bit serial number."""
         return self._rom[1:7]
 
     @property
-    def family_code(self):
+    def family_code(self) -> int:
         """The 8 bit family code."""
         return self._rom[0]
 
@@ -57,7 +63,7 @@ class OneWireAddress:
 class OneWireBus:
     """A class to represent a 1-Wire bus."""
 
-    def __init__(self, pin):
+    def __init__(self, pin: Pin) -> None:
         # pylint: disable=no-member
         self._ow = busio.OneWire(pin)
         self._readbit = self._ow.read_bit
@@ -65,21 +71,21 @@ class OneWireBus:
         self._maximum_devices = _MAX_DEV
 
     @property
-    def maximum_devices(self):
+    def maximum_devices(self) -> int:
         """The maximum number of devices the bus will scan for. Valid range is 1 to 255.
         It is an error to have more devices on the bus than this number. Having less is OK.
         """
         return self._maximum_devices
 
     @maximum_devices.setter
-    def maximum_devices(self, count):
+    def maximum_devices(self, count: int) -> None:
         if not isinstance(count, int):
             raise ValueError("Maximum must be an integer value 1 - 255.")
         if count < 1 or count > 0xFF:
             raise ValueError("Maximum must be an integer value 1 - 255.")
         self._maximum_devices = count
 
-    def reset(self, required=False):
+    def reset(self, required: bool = False) -> bool:
         """
         Perform a reset and check for presence pulse.
 
@@ -90,7 +96,9 @@ class OneWireBus:
             raise OneWireError("No presence pulse found. Check devices and wiring.")
         return not reset
 
-    def readinto(self, buf, *, start=0, end=None):
+    def readinto(
+        self, buf: bytearray, *, start: int = 0, end: Optional[int] = None
+    ) -> None:
         """
         Read into ``buf`` from the device. The number of bytes read will be the
         length of ``buf``.
@@ -108,7 +116,9 @@ class OneWireBus:
         for i in range(start, end):
             buf[i] = self._readbyte()
 
-    def write(self, buf, *, start=0, end=None):
+    def write(
+        self, buf: bytearray, *, start: int = 0, end: Optional[int] = None
+    ) -> None:
         """
         Write the bytes from ``buf`` to the device.
 
@@ -125,11 +135,11 @@ class OneWireBus:
         for i in range(start, end):
             self._writebyte(buf[i])
 
-    def scan(self):
+    def scan(self) -> List[OneWireAddress]:
         """Scan for devices on the bus and return a list of addresses."""
         devices = []
         diff = 65
-        rom = False
+        rom = None
         count = 0
         for _ in range(0xFF):
             rom, diff = self._search_rom(rom, diff)
@@ -146,18 +156,20 @@ class OneWireBus:
                 break
         return devices
 
-    def _readbyte(self):
+    def _readbyte(self) -> int:
         val = 0
         for i in range(8):
             val |= self._ow.read_bit() << i
         return val
 
-    def _writebyte(self, value):
+    def _writebyte(self, value: int) -> None:
         for i in range(8):
             bit = (value >> i) & 0x1
             self._ow.write_bit(bit)
 
-    def _search_rom(self, l_rom, diff):
+    def _search_rom(
+        self, l_rom: Optional[bytearray], diff: int
+    ) -> Tuple[bytearray, int]:
         if not self.reset():
             return None, 0
         self._writebyte(_SEARCH_ROM)
@@ -185,7 +197,7 @@ class OneWireBus:
         return rom, next_diff
 
     @staticmethod
-    def crc8(data):
+    def crc8(data: bytearray) -> int:
         """
         Perform the 1-Wire CRC check on the provided data.
 
